# Sithon
A small library used for test cases in Python, heavily inspired on V's test!

*This project was made for learning purposes, and is not meant to be used in real projects, but you can still use it, it
s just not 100% working well.*

# Supports
Only supports ``assert x == y`` so far.

Asynchronous test cases supported.